@@ -7,7 +7,7 @@ The primary interface to CLE is the Loader class.
 
 from __future__ import annotations
 
-__version__ = "9.2.123"
+__version__ = "9.2.160"
 
 from .address_translator import AT, AddressTranslator
 from .backends import (
@@ -74,7 +74,7 @@ from .errors import (
 )
 from .gdb import GDB_SEARCH_PATH, convert_info_proc_maps, convert_info_sharedlibrary
 from .loader import Loader
-from .memory import Clemory, ClemoryBase, ClemoryTranslator, ClemoryView
+from .memory import Clemory, ClemoryBase, ClemoryReadOnlyView, ClemoryTranslator, ClemoryView
 from .patched_stream import PatchedStream
 
 __all__ = [
@@ -133,6 +133,7 @@ __all__ = [
     "Loader",
     "Clemory",
     "ClemoryBase",
+    "ClemoryReadOnlyView",
     "ClemoryView",
     "ClemoryTranslator",
     "PatchedStream",
