@@ -1,3 +1,10 @@
+"""Relocation types for ARM.
+
+Reference: https://github.com/ARM-software/abi-aa/blob/main/aaelf32/aaelf32.rst#relocation-codes
+"""
+
+from __future__ import annotations
+
 import logging
 
 from cle.errors import CLEOperationError
@@ -17,10 +24,6 @@ from .generic import (
 )
 
 log = logging.getLogger(name=__name__)
-arch = "ARM"
-
-# Reference: "ELF for the ARM Architecture ABI r2.10"
-# http://infocenter.arm.com/help/topic/com.arm.doc.ihi0044e/IHI0044E_aaelf.pdf
 
 
 def _applyReloc(inst, result, mask=0xFFFFFFFF):
@@ -516,30 +519,131 @@ class R_ARM_GOT_PREL(GenericPCRelativeAddendReloc, RelocTruncate32Mixin, RelocGO
     """
 
 
-__all__ = [
-    "arch",
-    "R_ARM_CALL",
-    "R_ARM_PREL31",
-    "R_ARM_REL32",
-    "R_ARM_ABS32",
-    "R_ARM_MOVW_ABS_NC",
-    "R_ARM_MOVT_ABS",
-    "R_ARM_THM_CALL",
-    "R_ARM_COPY",
-    "R_ARM_GLOB_DAT",
-    "R_ARM_JUMP_SLOT",
-    "R_ARM_RELATIVE",
-    "R_ARM_ABS32_NOI",
-    "R_ARM_REL32_NOI",
-    "R_ARM_TLS_DTPMOD32",
-    "R_ARM_TLS_DTPOFF32",
-    "R_ARM_TLS_TPOFF32",
-    "R_ARM_JUMP24",
-    "R_ARM_PC24",
-    "R_ARM_THM_JUMP24",
-    "R_ARM_THM_JUMP19",
-    "R_ARM_THM_JUMP6",
-    "R_ARM_THM_MOVW_ABS_NC",
-    "R_ARM_THM_MOVT_ABS",
-    "R_ARM_GOT_PREL",
-]
+relocation_table_arm = {
+    1: R_ARM_PC24,
+    2: R_ARM_ABS32,
+    3: R_ARM_REL32,
+    # 4: ARM_LDR_PC_G0,
+    # 5: R_ARM_ABS16,
+    # 6: R_ARM_ABS12,
+    # 7: R_ARM_THM_ABS5,
+    # 8: R_ARM_ABS8,
+    # 9: R_ARM_SBREL32,
+    10: R_ARM_THM_CALL,
+    # 11: R_ARM_THM_PC8,
+    # 12: R_ARM_BREL_ADJ,
+    # 13: R_ARM_TLS_DESC,
+    # 14: R_ARM_THM_SWI8,
+    # 15: R_ARM_XPC25,
+    # 16: R_ARM_THM_XPC22,
+    17: R_ARM_TLS_DTPMOD32,
+    18: R_ARM_TLS_DTPOFF32,
+    19: R_ARM_TLS_TPOFF32,
+    20: R_ARM_COPY,
+    21: R_ARM_GLOB_DAT,
+    22: R_ARM_JUMP_SLOT,
+    23: R_ARM_RELATIVE,
+    # 24: R_ARM_GOTOFF,
+    # 25: R_ARM_BASE_PREL,
+    # 26: R_ARM_GOT_BREL,
+    # 27: R_ARM_PLT32,
+    28: R_ARM_CALL,
+    29: R_ARM_JUMP24,
+    30: R_ARM_THM_JUMP24,
+    # 31: R_ARM_BASE_ABS,
+    # 32: R_ARM_ALU_PCREL_7_0,
+    # 33: R_ARM_ALU_PCREL_15_8,
+    # 34: R_ARM_ALU_PCREL_23_15,
+    # 35: R_ARM_LDR_SBREL_11_0_NC,
+    # 36: R_ARM_ALU_SBREL_19_12_NC,
+    # 37: R_ARM_ALU_SBREL_27_20_CK,
+    # 38: R_ARM_TARGET1,
+    # 39: R_ARM_SBREL31,
+    # 40: R_ARM_V4BX,
+    # 41: R_ARM_TARGET2,
+    42: R_ARM_PREL31,
+    43: R_ARM_MOVW_ABS_NC,
+    44: R_ARM_MOVT_ABS,
+    # 45: R_ARM_MOVW_PREL_NC,
+    # 46: R_ARM_MOVT_PREL,
+    47: R_ARM_THM_MOVW_ABS_NC,
+    48: R_ARM_THM_MOVT_ABS,
+    # 49: R_ARM_THM_MOVW_PREL_NC,
+    # 50: R_ARM_THM_MOVT_PREL,
+    51: R_ARM_THM_JUMP19,
+    52: R_ARM_THM_JUMP6,
+    # 53: R_ARM_THM_ALU_PREL_11_0,
+    # 54: R_ARM_THM_PC12,
+    55: R_ARM_ABS32_NOI,
+    56: R_ARM_REL32_NOI,
+    # 57: R_ARM_ALU_PC_G0_NC,
+    # 58: R_ARM_ALU_PC_G0,
+    # 59: R_ARM_ALU_PC_G1_NC,
+    # 60: R_ARM_ALU_PC_G1,
+    # 61: R_ARM_ALU_PC_G2,
+    # 62: R_ARM_LDR_PC_G1,
+    # 63: R_ARM_LDR_PC_G2,
+    # 64: R_ARM_LDRS_PC_G0,
+    # 65: R_ARM_LDRS_PC_G1,
+    # 66: R_ARM_LDRS_PC_G2,
+    # 67: R_ARM_LDC_PC_G0,
+    # 68: R_ARM_LDC_PC_G1,
+    # 69: R_ARM_LDC_PC_G2,
+    # 70: R_ARM_ALU_SB_G0_NC,
+    # 71: R_ARM_ALU_SB_G0,
+    # 72: R_ARM_ALU_SB_G1_NC,
+    # 73: R_ARM_ALU_SB_G1,
+    # 74: R_ARM_ALU_SB_G2,
+    # 75: R_ARM_LDR_SB_G0,
+    # 76: R_ARM_LDR_SB_G1,
+    # 77: R_ARM_LDR_SB_G2,
+    # 78: R_ARM_LDRS_SB_G0,
+    # 79: R_ARM_LDRS_SB_G1,
+    # 80: R_ARM_LDRS_SB_G2,
+    # 81: R_ARM_LDC_SB_G0,
+    # 82: R_ARM_LDC_SB_G1,
+    # 83: R_ARM_LDC_SB_G2,
+    # 84: R_ARM_MOVW_BREL_NC,
+    # 85: R_ARM_MOVT_BREL,
+    # 86: R_ARM_MOVW_BREL,
+    # 87: R_ARM_THM_MOVW_BREL_NC,
+    # 88: R_ARM_THM_MOVT_BREL,
+    # 89: R_ARM_THM_MOVW_BREL,
+    # 90: R_ARM_TLS_GOTDESC,
+    # 91: R_ARM_TLS_CALL,
+    # 92: R_ARM_TLS_DESCSEQ,
+    # 93: R_ARM_THM_TLS_CALL,
+    # 94: R_ARM_PLT32_ABS,
+    # 95: R_ARM_GOT_ABS,
+    96: R_ARM_GOT_PREL,
+    # 97: R_ARM_GOT_BREL12,
+    # 98: R_ARM_GOTOFF12,
+    # 99: R_ARM_GOTRELAX,
+    # 100: R_ARM_GNU_VTENTRY,
+    # 101: R_ARM_GNU_VTINHERIT,
+    # 102: R_ARM_JUMP11,
+    # 103: R_ARM_THM_PC9,
+    # 104: R_ARM_TLS_GD32,
+    # 105: R_ARM_TLS_LDM32,
+    # 106: R_ARM_TLS_LDO32,
+    # 107: R_ARM_TLS_IE32,
+    # 108: R_ARM_TLS_LE32,
+    # 109: R_ARM_TLS_LDO12,
+    # 110: R_ARM_TLS_LE12,
+    # 111: R_ARM_TLS_IE12GP,
+    # 112-127: R_ARM_PRIVATE_<n>
+    # 128: R_ARM_ME_TOO,
+    # 129: R_ARM_THM_TLS_DESCSEQ16,
+    # 130: R_ARM_THM_TLS_DESCSEQ32,
+    # 131: R_ARM_THM_GOT_BREL12,
+    # 132: R_ARM_THM_ALU_ABS_G0_NC,
+    # 133: R_ARM_THM_ALU_ABS_G1_NC,
+    # 134: R_ARM_THM_ALU_ABS_G2_NC,
+    # 135: R_ARM_THM_ALU_ABS_G3,
+    # 136: R_ARM_THM_BF16,
+    # 137: R_ARM_THM_BF12,
+    # 138: R_ARM_THM_BF18,
+}
+
+
+__all__ = ("relocation_table_arm",)
